==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Videotallennus on käynnissä. Sulje ikkuna?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Sinulla ei ole lupaa käyttää tätä kansiota</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Virheellinen kansio</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Tiedoston sijainti</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Laukaise</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Sarjakuvaus</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Itselaukaisimen viive</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ulostulo</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Ulostulon muoto</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kpl</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kpl</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera on kuvan ja videon sieppaustyökalu, joka käyttää tietokoneen kameraa tai verkkokameraa.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Tiedostoa ei tallennettu</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Tallenna nimellä:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Kuva:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Tarkkuuden asetukset</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Tarkkuus:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Ota kuva</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Tallenna video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Lopeta kuvaaminen</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Verkkokameraa ei löytynyt</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Verkkokamera on käytössä</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Lopeta tallennus</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Videotallennus on käynnissä. Sulje ikkuna?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Sinulla ei ole lupaa käyttää tätä kansiota</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Virheellinen kansio</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Tiedoston sijainti</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Laukaise</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Sarjakuvaus</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Itselaukaisimen viive</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ulostulo</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Ulostulon muoto</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kpl</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kpl</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera on kuvan ja videon sieppaustyökalu, joka käyttää tietokoneen kameraa tai verkkokameraa.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Tiedostoa ei tallennettu</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Tallenna nimellä:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Kuva:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Tarkkuuden asetukset</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Tarkkuus:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Kuvat:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videot:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Äänitehosteet</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Lopeta tallennus</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä pikavalinnat</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Lopeta kuvaaminen</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Pikavalikko</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Ota kuva</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Tallenna video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Lopeta kuvaaminen</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Verkkokameraa ei löytynyt</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Verkkokamera on käytössä</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Lopeta tallennus</translation>
    </message>
</context>
</TS>
